import React, { useState, useRef, useEffect } from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var styles = {
  style: {
    fontFamily: 'Avenir',
    color: '#1890ff',
    border: '1px solid #1890ff',
    outline: 'none',
    height: '36px',
    fontSize: '15px',
    cursor: 'pointer',
    padding: '8px 16px',
    borderRadius: '33px',
    backgroundColor: 'white',
    transition: 'all .44s ease',
    WebkitTransition: 'all .44s ease',
    MozTransition: 'all .44s ease'
  },
  hoveredStyle: {
    opacity: '0.73'
  }
};

var Button = function Button(props) {
  var _props$type = props.type,
      type = _props$type === void 0 ? 'default' : _props$type;

  var _useState = useState(false),
      hovered = _useState[0],
      setHovered = _useState[1];

  var getTypeStyle = function getTypeStyle() {
    if (type == 'primary') {
      return primaryStyle;
    } else if (type === 'danger') {
      return dangerStyle;
    } else {
      return {};
    }
  };

  var typeStyle = getTypeStyle();
  return React.createElement("button", {
    onClick: props.onClick,
    className: "ce-" + type + "-button",
    onMouseEnter: function onMouseEnter() {
      return setHovered(true);
    },
    onMouseLeave: function onMouseLeave() {
      return setHovered(false);
    },
    style: _extends({}, styles.style, typeStyle, hovered ? styles.hoveredStyle : {}, props.style, hovered ? props.hoveredStyle : {})
  }, props.children);
};
var primaryStyle = {
  color: 'white',
  border: 'none',
  backgroundColor: '#1890ff'
};
var dangerStyle = {
  color: '#f5222d',
  backgroundColor: 'white',
  border: '1px solid #f5222d'
};

var styles$1 = {
  style: {
    fontFamily: 'Avenir',
    height: '36px',
    fontSize: '15px',
    outline: 'none',
    borderRadius: '24px',
    border: '1px solid #d9d9d9',
    padding: '0px 12px',
    boxSizing: 'border-box',
    transition: 'all .33s ease',
    WebkitTransition: 'all .33s ease',
    MozTransition: 'all .33s ease'
  },
  focusStyle: {
    border: '1px solid #1890ff'
  }
};

var Input = function Input(props) {
  var didMountRef = useRef(false);

  var _useState = useState(''),
      currentValue = _useState[0],
      setCurrentValue = _useState[1];

  var _useState2 = useState(false),
      focused = _useState2[0],
      setFocused = _useState2[1];

  useEffect(function () {
    if (!didMountRef.current) {
      didMountRef.current = true;

      if (props.defaultValue) {
        var event = {
          target: {
            value: currentValue
          }
        };
        props.onChange && props.onChange(event);
        setCurrentValue(props.defaultValue);
      }
    }
  });
  return React.createElement("input", {
    autoFocus: props.autoFocus,
    className: "ce-input ce-text-input",
    placeholder: props.label,
    value: typeof props.value === 'string' ? props.value : currentValue,
    onChange: function onChange(e) {
      setCurrentValue(e.target.value);
      props.onChange && props.onChange(e);
    },
    onFocus: function onFocus(e) {
      setFocused(true);
      props.onFocus && props.onFocus(e);
    },
    onBlur: function onBlur(e) {
      setFocused(false);
      props.onBlur && props.onBlur(e);
    },
    style: _extends({}, styles$1.style, focused ? styles$1.focusStyle : {}, props.style, focused ? props.focusStyle : {})
  });
};

var colors = ['#D64045', '#5B3000', '#00CC99', '#467599', '#1D3354', '#8F250C', '#6153CC', '#961D4E', '#A29F15', '#0CAADC', '#FF5154', '#FA7921', '#688E26', '#550527', '#A10702', '#FF1053', '#6C6EA0', '#100B00'];

var stringToNumber = function stringToNumber(str) {
  var sum = 0;

  for (var i = 0; i < str.length; i++) {
    sum += str.charCodeAt(i);
  }

  return sum;
};

var stringToColor = function stringToColor(str) {
  if (!str) {
    return 'black';
  } else {
    return colors[stringToNumber(str) % colors.length];
  }
};

var styles$2 = {
  style: {
    // Position
    position: 'relative',
    // Size
    width: '44px',
    paddingTop: '12px',
    paddingBottom: '12px',
    // Style
    borderRadius: '50%',
    backgroundRepeat: 'no-repeat',
    backgroundPosition: 'center',
    backgroundSize: '48px',
    // Text Style
    color: 'white',
    textAlign: 'center',
    fontFamily: 'Avenir',
    fontSize: '15px',
    fontWeight: 600
  },
  statusStyle: {
    // Position
    position: 'absolute',
    top: '0px',
    right: '0px',
    // Style
    width: '8px',
    height: '8px',
    borderRadius: '100%',
    border: '2px solid white'
  }
};

var Avatar = function Avatar(props) {
  var _props$username = props.username,
      username = _props$username === void 0 ? '' : _props$username,
      avatarUrl = props.avatarUrl;
  var text = username ? username.substring(0, 2).toUpperCase() : '';
  var color = stringToColor(username);

  var isString = function isString(avatarUrl) {
    return typeof avatarUrl === 'string';
  };

  var avatarUrlStyle = {
    backgroundColor: isString(avatarUrl) ? '#FFFFFF' : color,
    backgroundImage: isString(avatarUrl) && "url(" + avatarUrl + ")",
    height: "" + (isString(avatarUrl) ? '44px' : 'auto'),
    padding: "" + (isString(avatarUrl) ? '0px' : 'auto')
  };
  return React.createElement("div", {
    className: "ce-avatar",
    onClick: props.onClick,
    style: _extends({}, styles$2.style, avatarUrlStyle, props.style)
  }, !avatarUrl && text, React.createElement("div", {
    className: "ce-avatar-status",
    style: _extends({}, styles$2.statusStyle, {
      display: props.isOnline === undefined ? 'none' : 'auto',
      backgroundColor: props.isOnline ? '#52c41a' : '#f5222d'
    }, props.statusStyle)
  }));
};

var styles$3 = {
  style: {
    borderRadius: '13px',
    textAlign: 'center',
    backgroundRepeat: 'no-repeat',
    backgroundPosition: 'center',
    backgroundSize: '14px',
    // CSS Transitions
    transition: 'all .33s ease',
    WebkitTransition: 'all .33s ease',
    MozTransition: 'all .33s ease'
  }
};

var Dot = function Dot(props) {
  var _props$username = props.username,
      username = _props$username === void 0 ? '' : _props$username,
      _props$isVisible = props.isVisible,
      isVisible = _props$isVisible === void 0 ? true : _props$isVisible;
  var color = stringToColor(username);
  return React.createElement("div", {
    className: "ce-avatar-dot",
    style: _extends({}, styles$3.style, {
      backgroundColor: props.avatarUrl ? 'white' : color,
      backgroundImage: props.avatarUrl ? "url(" + props.avatarUrl + ")" : '',
      width: isVisible ? '13px' : '0px',
      height: isVisible ? '13px' : '0px'
    }, props.style)
  });
};

var styles$4 = {
  style: {
    width: '100%',
    paddingTop: '12px',
    height: 'calc(44px + 14px)'
  },
  oneAvatarStyle: {
    avatarOne: {
      "float": 'left',
      position: 'relative',
      left: 'calc(50% - 22px)'
    }
  },
  twoAvatarsStyle: {
    avatarOne: {
      "float": 'left',
      position: 'relative',
      left: 'calc(50% - 22px - 15px)'
    },
    avatarTwo: {
      "float": 'left',
      position: 'relative',
      left: 'calc(50% - 44px - 22px + 15px)'
    }
  },
  threeAvatarsStyle: {
    avatarOne: {
      "float": 'left',
      position: 'relative',
      left: 'calc(50% - 22px - 24px)'
    },
    avatarTwo: {
      "float": 'left',
      position: 'relative',
      left: 'calc(50% - 24px - 44px)'
    },
    avatarThree: {
      "float": 'left',
      position: 'relative',
      left: 'calc(50% - 22px - 44px - 44px + 24px)'
    }
  }
};

var ChatAvatars = function ChatAvatars(props) {
  var _props$users = props.users,
      users = _props$users === void 0 ? [] : _props$users,
      _props$oneAvatarStyle = props.oneAvatarStyle,
      oneAvatarStyle = _props$oneAvatarStyle === void 0 ? {
    avatarOne: {}
  } : _props$oneAvatarStyle,
      _props$twoAvatarsStyl = props.twoAvatarsStyle,
      twoAvatarsStyle = _props$twoAvatarsStyl === void 0 ? {
    avatarOne: {},
    avatarTwo: {}
  } : _props$twoAvatarsStyl,
      _props$threeAvatarsSt = props.threeAvatarsStyle,
      threeAvatarsStyle = _props$threeAvatarsSt === void 0 ? {
    avatarOne: {},
    avatarTwo: {},
    avatarThree: {}
  } : _props$threeAvatarsSt;
  var topPeople = users.slice(0, 3);
  var otherPerson = users.find(function (person) {
    return person.username !== props.myUsername;
  });

  var renderAvatars = function renderAvatars(people, avatarStyles) {
    if (people.length != avatarStyles.length) {
      return React.createElement("div", null);
    }

    return React.createElement("div", {
      style: _extends({}, styles$4.style, props.style)
    }, people.map(function (person, i) {
      return React.createElement("div", {
        style: avatarStyles[i],
        key: "avatar_" + i
      }, React.createElement(Avatar, {
        username: person.username,
        avatarUrl: person.avatar ? person.avatar : undefined
      }));
    }));
  };

  var renderOnePerson = function renderOnePerson(people) {
    var _styles$oneAvatarStyl;

    return renderAvatars(people, [_extends({}, (_styles$oneAvatarStyl = styles$4.oneAvatarStyle) == null ? void 0 : _styles$oneAvatarStyl.avatarOne, oneAvatarStyle.avatarOne)]);
  };

  var renderTwoPeople = function renderTwoPeople(people) {
    var _styles$twoAvatarsSty, _styles$twoAvatarsSty2;

    var avatarStyles = [_extends({}, (_styles$twoAvatarsSty = styles$4.twoAvatarsStyle) == null ? void 0 : _styles$twoAvatarsSty.avatarOne, twoAvatarsStyle.avatarOne), _extends({}, (_styles$twoAvatarsSty2 = styles$4.twoAvatarsStyle) == null ? void 0 : _styles$twoAvatarsSty2.avatarTwo, twoAvatarsStyle.avatarTwo)];
    return renderAvatars(people, avatarStyles);
  };

  var renderThreePeople = function renderThreePeople(people) {
    var _styles$threeAvatarsS, _styles$threeAvatarsS2, _styles$threeAvatarsS3;

    var avatarStyles = [_extends({}, (_styles$threeAvatarsS = styles$4.threeAvatarsStyle) == null ? void 0 : _styles$threeAvatarsS.avatarOne, threeAvatarsStyle.avatarOne), _extends({}, (_styles$threeAvatarsS2 = styles$4.threeAvatarsStyle) == null ? void 0 : _styles$threeAvatarsS2.avatarTwo, threeAvatarsStyle.avatarTwo), _extends({}, (_styles$threeAvatarsS3 = styles$4.threeAvatarsStyle) == null ? void 0 : _styles$threeAvatarsS3.avatarThree, threeAvatarsStyle.avatarThree)];
    return renderAvatars(people, avatarStyles);
  };

  return React.createElement("div", {
    className: "ce-chat-settings-container"
  }, React.createElement("div", {
    className: "ce-chat-avatars-row"
  }, topPeople.length === 1 && renderOnePerson(topPeople), props.isDirectChat && otherPerson && renderOnePerson([otherPerson]), !props.isDirectChat && otherPerson && topPeople.length === 2 && renderTwoPeople(topPeople), !props.isDirectChat && otherPerson && topPeople.length === 3 && renderThreePeople(topPeople)));
};

var styles$5 = {
  style: {
    position: 'relative',
    height: '64px',
    borderRadius: '12px',
    paddingBottom: '12px',
    cursor: 'pointer',
    transition: 'all .44s ease',
    WebkitTransition: 'all .44s ease',
    MozTransition: 'all .44s ease'
  },
  hoveredStyle: {
    backgroundColor: '#f5f5f5',
    border: '0px solid white'
  },
  activeStyle: {
    backgroundColor: '#d9d9d9',
    border: '0px solid white'
  },
  titleStyle: {
    // Position
    position: 'absolute',
    top: '12px',
    left: '12px',
    // Size
    width: 'calc(100% - 12px - 32px)',
    // Font
    fontWeight: 500,
    whiteSpace: 'nowrap',
    overflow: 'hidden',
    fontFamily: 'Avenir'
  },
  notificationStyle: {
    // Position
    position: 'absolute',
    top: 'calc(12px + 6px)',
    right: '12px',
    // Style
    width: '12px',
    height: '12px',
    borderRadius: '6px',
    backgroundColor: '#1890ff',
    "float": 'right'
  },
  subtitleStyle: {
    // Position
    position: 'absolute',
    bottom: '12px',
    left: '12px',
    // Size
    width: '70%',
    // Style
    color: 'rgba(153, 153, 153, 1)',
    fontSize: '14px',
    whiteSpace: 'nowrap',
    overflow: 'hidden',
    fontFamily: 'Avenir'
  },
  timeStampStyle: {
    // Position
    position: 'absolute',
    bottom: '12px',
    right: '12px',
    // Size
    width: '20%',
    // Style
    textAlign: 'right',
    color: 'rgba(153, 153, 153, 1)',
    fontSize: '14px',
    whiteSpace: 'nowrap',
    overflow: 'hidden',
    fontFamily: 'Avenir'
  },
  loadingBarStyle: {
    borderRadius: '4px',
    backgroundColor: '#e2e2e2',
    color: '#e2e2e2'
  }
};

var ChatCard = function ChatCard(props) {
  var _props$title = props.title,
      title = _props$title === void 0 ? '' : _props$title,
      _props$description = props.description,
      description = _props$description === void 0 ? '' : _props$description,
      _props$timeStamp = props.timeStamp,
      timeStamp = _props$timeStamp === void 0 ? '' : _props$timeStamp;

  var _useState = useState(false),
      hovered = _useState[0],
      setHovered = _useState[1];

  var loadingBarStyle = props.isLoading ? _extends({}, styles$5.loadingBarStyle, props.loadingBarStyle) : {};
  var hasNotificationStyle = props.hasNotification ? {} : {
    display: 'none'
  };

  if (props.renderChatCard) {
    return React.createElement(React.Fragment, null, props.renderChatCard(props));
  }

  return React.createElement("div", {
    onClick: props.onClick,
    onMouseEnter: function onMouseEnter() {
      return setHovered(true);
    },
    onMouseLeave: function onMouseLeave() {
      return setHovered(false);
    },
    style: _extends({}, styles$5.style, hovered ? styles$5.hoveredStyle : {}, props.isActive ? styles$5.activeStyle : {}, props.style, hovered ? props.hoveredStyle : {}, props.isActive ? props.activeStyle : {}),
    className: "\n        ce-chat-card \n        " + (props.isActive && 'ce-active-chat-card') + " \n        " + (hovered && 'ce-hovered-chat-card') + "\n      "
  }, React.createElement("div", {
    className: "ce-chat-card-title",
    style: _extends({}, styles$5.titleStyle, loadingBarStyle, props.titleStyle),
    id: "ce-chat-card-title-" + title
  }, props.isLoading ? '.' : title), React.createElement("div", {
    className: "ce-chat-card-unread",
    style: _extends({}, styles$5.notificationStyle, hasNotificationStyle, loadingBarStyle, props.notificationStyle)
  }), React.createElement("div", {
    className: "ce-chat-card-subtitle",
    style: _extends({}, styles$5.subtitleStyle, loadingBarStyle, props.subtitleStyle)
  }, React.createElement("div", {
    dangerouslySetInnerHTML: {
      __html: props.isLoading ? '.' : description
    }
  }), React.createElement("style", null, "p {margin-block-start: 0px; margin-block-end: 0px;}")), React.createElement("div", {
    className: "ce-chat-card-time-stamp",
    style: _extends({}, styles$5.timeStampStyle, loadingBarStyle, props.timeStampStyle)
  }, props.isLoading ? '.' : timeStamp));
};

var styles$6 = {
  style: {
    fontFamily: 'Avenir'
  }
};

var RenderTrigger = function RenderTrigger(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? 'Loading...' : _props$children;

  var useOnScreen = function useOnScreen(ref) {
    var _useState = useState(false),
        isIntersecting = _useState[0],
        setIntersecting = _useState[1];

    var observer = new IntersectionObserver(function (_ref) {
      var entry = _ref[0];
      setIntersecting(entry.isIntersecting);

      if (entry.isIntersecting) {
        props.onShow && props.onShow();
      } else {
        props.onHide && props.onHide();
      }
    });
    useEffect(function () {
      observer.observe(ref.current);
      return function () {
        return observer.disconnect();
      };
    }, []);
    return isIntersecting;
  };

  var ref = useRef(null);
  ref !== null && useOnScreen(ref);
  return React.createElement("div", {
    ref: ref,
    style: _extends({}, styles$6.style, props.style),
    className: "ce-chat-loader"
  }, children);
};

export { Avatar, Button, ChatAvatars, ChatCard, Dot, Input, RenderTrigger };
//# sourceMappingURL=react-chat-engine-components.esm.js.map
